@@ -1,10 +1,11 @@
 from __future__ import division
 
-from numpy import dot, empty, sqrt
 from numpy import sum as npsum
-from numpy_sugar.linalg import cho_solve, ddot, dotd, sum2diag
+from numpy import dot, empty, sqrt, concatenate, zeros
 from scipy.linalg import cho_factor
 
+from numpy_sugar.linalg import cho_solve, ddot, dotd, sum2diag
+
 
 class Posterior(object):
     r"""EP posterior.
@@ -17,27 +18,16 @@ class Posterior(object):
           \tilde{\boldsymbol\mu} + \mathrm K^{-1}\mathbf m),
           (\tilde{\mathrm T} + \mathrm K^{-1})^{-1}\right).
     """
+
     def __init__(self, site):
         n = len(site.tau)
         self.tau = empty(n)
         self.eta = empty(n)
         self._site = site
         self._mean = None
-        self._QS = None
+        self._cov = None
 
-    def set_prior_mean(self, mean):
-        self._mean = mean
-
-    def set_prior_cov(self, QS):
-        self._QS = QS
-
-    def prior_mean(self):
-        return self._mean
-
-    def prior_cov(self):
-        return self._QS
-
-    def initialize(self):
+    def _initialize(self):
         r"""Initialize the mean and covariance of the posterior.
 
         Given that :math:`\tilde{\mathrm T}` is a matrix of zeros right before
@@ -50,11 +40,34 @@ class Posterior(object):
 
         as the initial posterior mean and covariance.
         """
-        self.tau[:] = 1 / npsum((self._QS[0] * sqrt(self._QS[1]))**2,
-                                axis=1)
+        if self._mean is None or self._cov is None:
+            return
+
+        Q = self._cov['QS'][0][0]
+        S = self._cov['QS'][1]
+
+        self.tau[:] = 1 / npsum((Q * sqrt(S))**2, axis=1)
         self.eta[:] = self._mean
         self.eta[:] *= self.tau
 
+    @property
+    def mean(self):
+        self._initialize()
+        return self._mean
+
+    @mean.setter
+    def mean(self, v):
+        self._mean = v
+
+    @property
+    def cov(self):
+        return self._cov
+
+    @cov.setter
+    def cov(self, v):
+        self._initialize()
+        self._cov = v
+
     def L(self):
         r"""Cholesky decomposition of :math:`\mathrm B`.
 
@@ -63,36 +76,35 @@ class Posterior(object):
             \mathrm B = \mathrm Q^{\intercal}\tilde{\mathrm{T}}\mathrm Q
                 + \mathrm{S}^{-1}
         """
-        QS = self._QS
-        B = dot(QS[0].T, ddot(self._site.tau, QS[0], left=True))
-        sum2diag(B, 1. / QS[1], out=B)
+        Q = self._cov['QS'][0][0]
+        S = self._cov['QS'][1]
+        B = dot(Q.T, ddot(self._site.tau, Q, left=True))
+        sum2diag(B, 1. / S, out=B)
         return cho_factor(B, lower=True)[0]
 
-    # def QS(self):
-    #     r"""Eigen decomposition of :math:`\mathrm K`"""
-    #     QS = economic_qs(self._cov)
-    #     return QS[0][0], QS[1]
-
     def _BiQt(self):
-        return cho_solve(self.L(), self._QS[0].T)
+        Q = self._cov['QS'][0][0]
+        return cho_solve(self.L(), Q.T)
 
     def update(self):
-        QS = self._QS
-        cov = dot(ddot(QS[0], QS[1], left=False), QS[0].T)
+        Q = self._cov['QS'][0][0]
+        S = self._cov['QS'][1]
+
+        K = dot(ddot(Q, S, left=False), Q.T)
 
         BiQt = self._BiQt()
-        TK = ddot(self._site.tau, cov, left=True)
+        TK = ddot(self._site.tau, K, left=True)
         BiQtTK = dot(BiQt, TK)
 
-        self.tau[:] = cov.diagonal()
-        self.tau -= dotd(QS[0], BiQtTK)
-        self.tau[:] = 1/self.tau
+        self.tau[:] = K.diagonal()
+        self.tau -= dotd(Q, BiQtTK)
+        self.tau[:] = 1 / self.tau
 
         assert all(self.tau >= 0.)
 
-        self.eta[:] = dot(cov, self._site.eta)
+        self.eta[:] = dot(K, self._site.eta)
         self.eta[:] += self._mean
-        self.eta[:] -= dot(QS[0], dot(BiQtTK, self._site.eta))
-        self.eta[:] -= dot(QS[0], dot(BiQt, self._site.tau * self._mean))
+        self.eta[:] -= dot(Q, dot(BiQtTK, self._site.eta))
+        self.eta[:] -= dot(Q, dot(BiQt, self._site.tau * self._mean))
 
         self.eta *= self.tau
