@@ -1,9 +1,11 @@
 from __future__ import division
 
-from numpy import zeros, maximum
+from numpy import maximum, zeros
 
-class Site(object): # pylint: disable=R0903
+
+class Site(object):  # pylint: disable=R0903
     r"""EP parameters."""
+
     def __init__(self, n):
         self.tau = zeros(n)
         self.eta = zeros(n)
