@@ -6,10 +6,8 @@ from liknorm import LikNormMachine
 from numpy import (asarray, clip, concatenate, dot, exp, inf, log, ndarray,
                    zeros)
 from numpy.linalg import LinAlgError
-
 from numpy_sugar import epsilon
 from optimix import Function, Scalar, Vector
-from optimix.optimize import BadSolutionError
 
 from ..ep import EPLinearKernel
 
@@ -74,7 +72,7 @@ class GLMM(EPLinearKernel, Function):
         >>> glmm = GLMM(y, 'binomial', X, QS)
         >>> print('Before: %.4f' % glmm.feed().value())
         Before: -95.1854
-        >>> glmm.feed().maximize(progress=False)
+        >>> glmm.feed().maximize(verbose=False)
         >>> print('After: %.2f' % glmm.feed().value())
         After: -92.24
     """
@@ -177,7 +175,7 @@ class GLMM(EPLinearKernel, Function):
 
     @property
     def beta(self):
-        return self.variables().get('beta').value
+        return asarray(self.variables().get('beta').value, float)
 
     @beta.setter
     def beta(self, v):
@@ -232,8 +230,7 @@ class GLMM(EPLinearKernel, Function):
             g = self._lml_derivatives(self._X)
             ev = exp(-v)
             grad = [
-                g['delta'] * (ev/(1 + ev))/(1 + ev),
-                g['scale'] * exp(x),
+                g['delta'] * (ev / (1 + ev)) / (1 + ev), g['scale'] * exp(x),
                 g['mean']
             ]
         except (ValueError, LinAlgError) as e:
@@ -244,3 +241,7 @@ class GLMM(EPLinearKernel, Function):
             raise BadSolutionError(str(e))
 
         return dict(logitdelta=grad[0], logscale=grad[1], beta=grad[2])
+
+
+class BadSolutionError(Exception):
+    pass
