@@ -1,16 +1,15 @@
 import pytest
-
+from numpy import asarray, ascontiguousarray, dot, ones, sqrt, zeros
 from numpy.random import RandomState
 from numpy.testing import assert_allclose
-from numpy import ascontiguousarray, sqrt, ones, dot, zeros, asarray
 from numpy_sugar.linalg import economic_qs, economic_qs_linear
 
 from glimix_core.example import linear_eye_cov
 from glimix_core.glmm import GLMM
 from glimix_core.random import bernoulli_sample
-
 from optimix import check_grad
 
+
 def test_glmm_precise():
     random = RandomState(0)
     X = random.randn(100, 5)
@@ -40,6 +39,7 @@ def test_glmm_precise():
 
     assert_allclose(check_grad(glmm), 0, atol=1e-4)
 
+
 def test_glmm_delta0():
     random = RandomState(0)
     X = random.randn(100, 5)
@@ -57,6 +57,7 @@ def test_glmm_delta0():
     assert_allclose(glmm.value(), -294.3289786264443)
     assert_allclose(check_grad(glmm, step=1e-5), 0, atol=1e-2)
 
+
 def test_glmm_delta1():
     random = RandomState(0)
     X = random.randn(100, 5)
@@ -74,6 +75,7 @@ def test_glmm_delta1():
     assert_allclose(glmm.value(), -317.9043148331947)
     assert_allclose(check_grad(glmm), 0, atol=1e-4)
 
+
 def test_glmm_wrong_qs():
     random = RandomState(0)
     X = random.randn(10, 15)
@@ -86,6 +88,7 @@ def test_glmm_wrong_qs():
     with pytest.raises(ValueError):
         print(GLMM((nsuc, ntri), 'binomial', X, QS))
 
+
 def test_glmm_optimize():
     random = RandomState(0)
     X = random.randn(100, 5)
@@ -105,17 +108,18 @@ def test_glmm_optimize():
     glmm.fix('beta')
     glmm.fix('scale')
 
-    glmm.feed().maximize(progress=False)
+    glmm.feed().maximize(verbose=False)
 
     assert_allclose(glmm.value(), -299.47042725069565)
 
     glmm.unfix('beta')
     glmm.unfix('scale')
 
-    glmm.feed().maximize(progress=False)
+    glmm.feed().maximize(verbose=False)
 
     assert_allclose(glmm.value(), -159.1688201218538, rtol=1e-06)
 
+
 def test_glmm_optimize_low_rank():
     random = RandomState(0)
     X = random.randn(100, 5)
@@ -132,13 +136,14 @@ def test_glmm_optimize_low_rank():
     glmm = GLMM((nsuc, ntri), 'binomial', X, QS)
 
     assert_allclose(glmm.value(), -179.73542932110485)
-    glmm.feed().maximize(progress=False)
+    glmm.feed().maximize(verbose=False)
     assert_allclose(glmm.value(), -155.4794212740998, rtol=1e-06)
 
+
 def test_glmm_bernoulli_problematic():
     random = RandomState(1)
     N = 500
-    G = random.randn(N, N+50)
+    G = random.randn(N, N + 50)
     y = bernoulli_sample(0.0, G, random_state=random)
     y = (y, )
 
@@ -154,12 +159,13 @@ def test_glmm_bernoulli_problematic():
     model = GLMM(y, 'bernoulli', X, QS=(QS[0], QS[1]))
     model.delta = 0
     model.fix('delta')
-    model.feed().maximize(progress=False)
+    model.feed().maximize(verbose=False)
     assert_allclose(model.feed().value(), -344.86474884323525)
     assert_allclose(model.delta, 0, atol=1e-3)
     assert_allclose(model.scale, 0.6026005889095781, rtol=1e-5)
     assert_allclose(model.beta, [-0.01806123661347892])
 
+
 def _stdnorm(X, axis=None, out=None):
     X = ascontiguousarray(X)
     if out is None:
@@ -179,6 +185,7 @@ def _stdnorm(X, axis=None, out=None):
 
     return out
 
+
 def test_glmm_binomial_pheno_list():
     random = RandomState(0)
     nsamples = 50
@@ -198,7 +205,7 @@ def test_glmm_binomial_pheno_list():
 
     QS = economic_qs(K)
     glmm = GLMM(y, 'binomial', X, QS)
-    glmm.feed().maximize(progress=False)
+    glmm.feed().maximize(verbose=False)
 
     assert_allclose(glmm.value(), -64.84586890596634)
 
@@ -220,6 +227,7 @@ def test_glmm_scale_very_low():
 
     assert_allclose(check_grad(glmm), 0, atol=1e-2)
 
+
 def test_glmm_scale_very_high():
     random = RandomState(0)
     X = random.randn(100, 5)
@@ -237,6 +245,7 @@ def test_glmm_scale_very_high():
 
     assert_allclose(check_grad(glmm), 0, atol=1e-3)
 
+
 def test_glmm_delta_zero():
     random = RandomState(0)
     X = random.randn(100, 5)
@@ -253,10 +262,11 @@ def test_glmm_delta_zero():
     assert_allclose(glmm.value(), -294.3289786264443)
     assert_allclose(check_grad(glmm, step=1e-4), 0, atol=1e-2)
 
-    glmm.feed().maximize(progress=False)
+    glmm.feed().maximize(verbose=False)
     assert_allclose(glmm.value(), -263.56884343483136)
     assert_allclose(glmm.delta, 1)
 
+
 def test_glmm_delta_one():
     random = RandomState(0)
     X = random.randn(100, 5)
@@ -280,6 +290,6 @@ def test_glmm_delta_one():
     assert_allclose(glmm.value(), -426.18257638533225)
     assert_allclose(check_grad(glmm, step=1e-4), 0, atol=1e-2)
 
-    glmm.feed().maximize(progress=False)
+    glmm.feed().maximize(verbose=False)
     assert_allclose(glmm.value(), -20.657040329898603)
     assert_allclose(glmm.delta, 0.01458391103525475, rtol=1e-4)
