@@ -1,15 +1,17 @@
 from __future__ import division
 
-from numpy import append, dot, empty, log, full
+import logging
+
 from numpy import sum as npsum
-
+from numpy import append, dot, empty, full, log, zeros
+from numpy.linalg import LinAlgError
+from numpy_sugar.linalg import rsolve, solve
 from tqdm import tqdm
 
-from numpy_sugar.linalg import solve
-
 LOG2PI = 1.837877066409345339081937709124758839607238769531250
 
-class FastScanner(object): # pylint: disable=R0903
+
+class FastScanner(object):  # pylint: disable=R0903
     r"""Fast inference over multiple covariates.
 
     Let :math:`\tilde{\mathrm M}_i` be a column-matrix of fixed-effect
@@ -33,6 +35,7 @@ class FastScanner(object): # pylint: disable=R0903
 
         self._QS = QS
         self._diags = [(1 - delta) * QS[1] + delta, delta]
+        self._logger = logging.getLogger(__name__)
 
         yTQ = [dot(y.T, Q) for Q in QS[0]]
         MTQ = [dot(M.T, Q) for Q in QS[0]]
@@ -40,7 +43,7 @@ class FastScanner(object): # pylint: disable=R0903
         self._yTQdiag = [l / r for (l, r) in zip(yTQ, self._diags)]
 
         self._a = [(i**2 / j).sum() for (i, j) in zip(yTQ, self._diags)]
-        self._b = [dot(i, j.T) for(i, j) in zip(self._yTQdiag, MTQ)]
+        self._b = [dot(i, j.T) for (i, j) in zip(self._yTQdiag, MTQ)]
 
         self._MTQdiag = [i / j for (i, j) in zip(MTQ, self._diags)]
 
@@ -116,11 +119,24 @@ class FastScanner(object): # pylint: disable=R0903
             self._C[0][-1, -1] = c_11[0][i]
             self._C[1][-1, -1] = c_11[1][i]
 
-            beta = solve(self._C[1] - self._C[0], b11m - b00m)
+            try:
+                beta = solve(self._C[1] - self._C[0], b11m - b00m)
+            except LinAlgError:
+                try:
+                    beta = rsolve(self._C[1] - self._C[0], b11m - b00m)
+                except LinAlgError:
+                    msg = "Could not converge to the optimal"
+                    msg += " effect-size of one of the candidates."
+                    msg += " Setting its effect-size to zero."
+                    self._logger.warning(warn)
+                    beta = zeros(self._C[1].shape[0])
+
             effect_sizes[i] = beta[-1]
 
-            p0 = self._a[1] - 2 * b11m.dot(beta) + beta.dot(self._C[1].dot(beta))
-            p1 = self._a[0] - 2 * b00m.dot(beta) + beta.dot(self._C[0]).dot(beta)
+            p0 = self._a[1] - 2 * b11m.dot(beta) + beta.dot(
+                self._C[1].dot(beta))
+            p1 = self._a[0] - 2 * b00m.dot(beta) + beta.dot(
+                self._C[0]).dot(beta)
 
             scale = (p0 + p1) / markers.shape[0]
 
